@@ -93,7 +93,7 @@ class WebsocketAgentTransport(AgentTransport):
 
             except InvalidStatusCode as e:
                 logger.warning(
-                    "Websocket Connect was denied. Trying to reload token",
+                    f"Websocket to {self.endpoint_url}?token={token}&instance_id={instance_id} was denied. Trying to reload token",
                     exc_info=True,
                 )
                 reload_token = True
