@@ -6,9 +6,8 @@ from rekuest.structures.registry import StructureRegistry
 import asyncio
 from typing import Any, Union
 from rekuest.api.schema import (
-    ArgPortFragment,
+    PortFragment,
     PortKind,
-    ReturnPortFragment,
     ChildPortFragment,
     DefinitionInput,
     DefinitionFragment,
@@ -23,7 +22,7 @@ from rekuest.definition.validate import auto_validate
 
 
 async def aexpand_arg(
-    port: Union[ArgPortFragment, ChildPortFragment],
+    port: Union[PortFragment, ChildPortFragment],
     value: Union[str, int, float, dict, list],
     structure_registry,
 ) -> Any:
@@ -151,7 +150,7 @@ async def expand_inputs(
 
 
 async def ashrink_return(
-    port: Union[ReturnPortFragment, ChildPortFragment],
+    port: Union[PortFragment, ChildPortFragment],
     value: Any,
     structure_registry=None,
 ) -> Union[str, int, float, dict, list, None]:
